<?php
/**
 * Plugin Name: Currency Converter Rub Widget
 * Plugin URI: http://paha.khspu.ru/blog
 * Text Domain: ccr
 * Domain Path: /languages 
 * Description: This widget displays the Russian ruble, according to central bank (cbr). (Этот виджет отображает Российский рубль, по курсу ЦБ (cbr).
 * Version: 1.2.2
 * Author: PahaW
 * Author URI: http://paha.khspu.ru/blog/
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 */

/**
 * Add function to widgets_init that'll load our widget.
 * @since 0.1
 */
add_action( 'widgets_init', 'ccr_load_widgets' );


/**
 * Register our widget.
 * 'Currency Converter Rub Widget' is the widget class used below.
 *
 * @since 0.1
 */
 
function ccr_load_widgets() {
	register_widget( 'Currency_Converter_Rub_Widget' );
}

/**
 * Currency Converter Rub Widget class.
 * This class handles everything that needs to be handled with the widget:
 * the settings, form, display, and update.  Nice!
 *
 * @since 0.1
 */
 

class Currency_Converter_Rub_Widget extends WP_Widget {

	/**
	 * Widget setup.
	 */
	function Currency_Converter_Rub_Widget() {
		/* Widget settings. */
		$widget_ops = array( 'classname' => 'ccr', 'description' => __('Данный Widget показывает курс рубля согласно ЦБ РФ.', 'ccr') );

		/* Widget control settings. */
		$control_ops = array( 'width' => 300, 'height' => 350, 'id_base' => 'ccr-widget' );

		/* Create the widget. */
		$this->WP_Widget( 'ccr-widget', __('Курс Российского рубля Widget', 'ccr'), $widget_ops, $control_ops );
	}

  // Get xml page (cbr.ru)
  function get_content(){ 
          global $link_date;
          // Формируем ссылку 
          $link = "http://www.cbr.ru/scripts/XML_daily.asp?date_req={$link_date}"; 
          // Загружаем HTML-страницу 
          $fd = fopen($link, "r"); 
          $text=""; 
          if (!$fd) _e('Запрашиваемая страница не найдена', 'ccr'); 
          else 
              { 
              // Чтение содержимого файла в переменную $text 
              while (!feof ($fd)) $text .= fgets($fd, 4096); 
              } 
          // Закрыть открытый файловый дескриптор 
          fclose ($fd); 
          return $text; 
  }
	/**
	 * How to display the widget on the screen.
	 */
	function widget( $args, $instance ) {
		extract( $args );
		/* Our variables from the widget settings. */
		$title = apply_filters('widget_title', $instance['title'] );
		$name = $instance['name'];
		$currency = $instance['currency'];
		$number = $instance['number'];
		$for_sale = $instance['for_sale'];
		$status = $instance['status'];
		$images = $instance['images'];
    $show_us = isset( $instance['show_us'] ) ? $instance['show_us'] : 0;
		$show_eu = isset( $instance['show_eu'] ) ? $instance['show_eu'] : 0;
		$show_kr = isset( $instance['show_kr'] ) ? $instance['show_kr'] : 0;
		$show_jp = isset( $instance['show_jp'] ) ? $instance['show_jp'] : 0;
		$show_ch = isset( $instance['show_jp'] ) ? $instance['show_jp'] : 0;
		$show_gb = isset( $instance['show_gb'] ) ? $instance['show_gb'] : 0;

		/* Before widget (defined by themes). */
		echo $before_widget;

		/* Display the widget title if one was input (before and after defined by themes). */
		if ( $title )
			echo $before_title . $title . $after_title;

    // Time zone (Khabarovsk)
    $timezone=+10;
    // Create date
    $date=gmdate("j.m.Y", time() + 3600*($timezone+date("I")));
    // Create date for link
    $link_date=date("d/m/Y");
    
    // Получаем текущие курсы валют в rss-формате с сайта www.cbr.ru 
    $content = $this->get_content(); 
    // Разбираем содержимое, при помощи регулярных выражений 
    $pattern = "#<Valute ID=\"([^\"]+)[^>]+>[^>]+>([^<]+)[^>]+>[^>]+>[^>]+>[^>]+>[^>]+>[^>]+>([^<]+)[^>]+>[^>]+>([^<]+)#i"; 
    preg_match_all($pattern, $content, $out, PREG_SET_ORDER); 
    $dollar = "";
    $euro = "";
    $iena = "";
    $von = "";
    $ch = "";
    $gb = "";
    foreach($out as $cur){ 
        if($cur[2] == 840) $dollar = str_replace(",",".",$cur[4]); 
        if($cur[2] == 978) $euro   = str_replace(",",".",$cur[4]); 
        if($cur[2] == 392) $iena   = str_replace(",",".",$cur[4]); 
        if($cur[2] == 410) $von    = str_replace(",",".",$cur[4]);
        if($cur[2] == 156) $ch     = str_replace(",",".",$cur[4]);
        if($cur[2] == 826) $gb     = str_replace(",",".",$cur[4]);
    } 
    if ( $status == 'enabled') {
		/* If show valute was selected, display valute. */
		echo "<table border='1' width='100%' align='center' class='kurs'>";
		/* Display name from widget settings if one was input. */
		if ( $name )
			printf( '<caption>' . __('%1$s '.$date, 'ccr') . '</caption>', $name );   
    echo "<thead><tr><th>{$currency}</th><th>{$number}</th><th><img src='".WP_PLUGIN_URL ."/currency-converter-rub/images/".$images."/ru.gif' alt='".__('Рубль', 'ccr')."' border='0'>&nbsp;RUB<br/>{$for_sale}</th></tr></thead>";
    echo "<tbody>";
    if ( $show_us )
        echo "<tr><td id='cvet'><img src='".WP_PLUGIN_URL ."/currency-converter-rub/images/".$images."/us.gif' alt='".__('Доллар США', 'ccr')."' border='0'>&nbsp;USD<td>1</td><td>{$dollar}</td></tr>";
    if ( $show_eu )
        echo "<tr><td id='cvet'><img src='".WP_PLUGIN_URL ."/currency-converter-rub/images/".$images."/eu.gif' alt='".__('Евро', 'ccr')."' border='0'>&nbsp;EUR</td><td>1</td><td>{$euro}</td></tr>";
    if ( $show_kr )
        echo "<tr><td id='cvet'><img src='".WP_PLUGIN_URL ."/currency-converter-rub/images/".$images."/kr.gif' alt='".__('Вон Республики Корея', 'ccr')."' border='0'>&nbsp;KRW</td><td>1000</td><td>{$von}</td></tr>";
    if ( $show_jp )
        echo "<tr><td id='cvet'><img src='".WP_PLUGIN_URL ."/currency-converter-rub/images/".$images."/jp.gif' alt='".__('Японских иен', 'ccr')."' border='0'>&nbsp;JPY</td><td>100</td><td>{$iena}</td></tr>";
    if ( $show_gb )
        echo "<tr><td id='cvet'><img src='".WP_PLUGIN_URL ."/currency-converter-rub/images/".$images."/uk.gif' alt='".__('Фунт стерлингов Соединенного королевства', 'ccr')."' border='0'>&nbsp;GBP</td><td>1</td><td>{$gb}</td></tr>";
    if ( $show_ch )
        echo "<tr><td id='cvet'><img src='".WP_PLUGIN_URL ."/currency-converter-rub/images/".$images."/cn.gif' alt='".__('Китайских юаней', 'ccr')."' border='0'>&nbsp;CNY</td><td>10</td><td>{$ch}</td></tr>";
    echo "</tbody>";
    echo "</table>";
    } else {
       echo '<p>'.__('Плагин курс валют отключен!', 'ccr').'</p>';       
    }
		/* After widget (defined by themes). */
		echo $after_widget;
	}

	/**
	 * Update the widget settings.
	 */
	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;

		/* Strip tags for title and name to remove HTML (important for text inputs). */
		$instance['title'] = strip_tags( $new_instance['title'] );
		$instance['name'] = strip_tags( $new_instance['name'] );
    $instance['currency'] = strip_tags( $new_instance['currency'] );
    $instance['number'] = strip_tags( $new_instance['number'] );
    $instance['for_sale'] = strip_tags( $new_instance['for_sale'] );

		/* No need to strip tags for sex and show_sex. */
		$instance['status'] = $new_instance['status'];
		$instance['images'] = $new_instance['images'];
		$instance['show_us'] = $new_instance['show_us'];
		$instance['show_eu'] = $new_instance['show_eu'];
		$instance['show_kr'] = $new_instance['show_kr'];
		$instance['show_jp'] = $new_instance['show_jp'];
		$instance['show_ch'] = $new_instance['show_ch'];
		$instance['show_gb'] = $new_instance['show_gb'];

		return $instance;
	}

	/**
	 * Displays the widget settings controls on the widget panel.
	 * Make use of the get_field_id() and get_field_name() function
	 * when creating your form elements. This handles the confusing stuff.
	 */
	function form( $instance ) {
    #$this->load_textdomain();
		/* Set up some default widget settings. */
		$defaults = array( 'title' => __('Курс валют', 'ccr'), 'name' => __('Ежедневный курс иностранной валюты ЦБ РФ на ', 'ccr'), 'currency' => __('Валюта', 'ccr'), 'number' => __('Кол-во', 'ccr'), 'for_sale' => __('Продажа (руб.)', 'ccr'), 'images' => 'big', 'status' => 'enabled', 'show_us' => 1, 'show_eu' => 1, 'show_kr' => 1, 'show_jp' => 1, 'show_gb' => 1, 'show_ch' => 1 );
		$instance = wp_parse_args( (array) $instance, $defaults ); ?>

		<!-- Widget Title: Text Input -->
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e('Заголовок:', 'ccr'); ?></label>
			<input id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo $instance['title']; ?>" style="width:100%;" />
		</p>

		<!-- Текст: Text Input -->
		<p>
			<label for="<?php echo $this->get_field_id( 'name' ); ?>"><?php _e('Текст:', 'ccr'); ?></label>
			<input id="<?php echo $this->get_field_id( 'name' ); ?>" name="<?php echo $this->get_field_name( 'name' ); ?>" value="<?php echo $instance['name']; ?>" style="width:100%;" />
		</p>
		
		<!-- Left block: Text Input -->
		<p>
			<label for="<?php echo $this->get_field_id( 'currency' ); ?>"><?php _e('Левый блок:', 'ccr'); ?></label>
			<input id="<?php echo $this->get_field_id( 'currency' ); ?>" name="<?php echo $this->get_field_name( 'currency' ); ?>" value="<?php echo $instance['currency']; ?>" style="width:100%;" />
		</p>
		
		<!-- Middle block: Text Input -->
		<p>
			<label for="<?php echo $this->get_field_id( 'number' ); ?>"><?php _e('Средний блок:', 'ccr'); ?></label>
			<input id="<?php echo $this->get_field_id( 'number' ); ?>" name="<?php echo $this->get_field_name( 'number' ); ?>" value="<?php echo $instance['number']; ?>" style="width:100%;" />
		</p>


		<!-- Right block: Text Input -->
		<p>
			<label for="<?php echo $this->get_field_id( 'for_sale' ); ?>"><?php _e('Правый блок:', 'ccr'); ?></label>
			<input id="<?php echo $this->get_field_id( 'for_sale' ); ?>" name="<?php echo $this->get_field_name( 'for_sale' ); ?>" value="<?php echo $instance['for_sale']; ?>" style="width:100%;" />
		</p>


    <!-- Set of images: Select Box -->
		<p>
			<label for="<?php echo $this->get_field_id( 'images' ); ?>"><?php _e('Набор картинок:', 'ccr'); ?></label> 
			<select id="<?php echo $this->get_field_id( 'images' ); ?>" name="<?php echo $this->get_field_name( 'images' ); ?>" class="widefat" style="width:100%;">
				<option value="big" <?php selected( $instance['images'], 'big' ); ?>>Большие</option>
				<option value="middle" <?php selected( $instance['images'], 'middle' ); ?>>Средние</option>
				<option value="small" <?php selected( $instance['images'], 'small' ); ?>>Маленькие</option>
			</select>
		</p>
		
		<!-- Status: Select Box -->
		<p>
			<label for="<?php echo $this->get_field_id( 'status' ); ?>"><?php _e('Состояние:', 'ccr'); ?></label> 
			<select id="<?php echo $this->get_field_id( 'status' ); ?>" name="<?php echo $this->get_field_name( 'status' ); ?>" class="widefat" style="width:100%;">
				<option value="enabled" <?php selected( $instance['status'], 'enabled' ); ?>>Включен</option>
				<option value="disabled" <?php selected( $instance['status'], 'disabled' ); ?>>Выключен</option>
			</select>
		</p>

		<!-- Show US? Checkbox -->
		<p>
			<input class="checkbox" type="checkbox" value="1" <?php checked( $instance['show_us'], 1 ); ?> id="<?php echo $this->get_field_id( 'show_us' ); ?>" name="<?php echo $this->get_field_name( 'show_us' ); ?>" /> 
			<label for="<?php echo $this->get_field_id( 'show_us' ); ?>"><?php _e('Включить US?', 'ccr'); ?></label>
		</p>

		<!-- Show EU? Checkbox -->
		<p>
			<input class="checkbox" type="checkbox" value="1" <?php checked( $instance['show_eu'], 1 ); ?> id="<?php echo $this->get_field_id( 'show_eu' ); ?>" name="<?php echo $this->get_field_name( 'show_eu' ); ?>" /> 
			<label for="<?php echo $this->get_field_id( 'show_eu' ); ?>"><?php _e('Включить EU?', 'ccr'); ?></label>
		</p>

		<!-- Show KR? Checkbox -->
		<p>
			<input class="checkbox" type="checkbox" value="1" <?php checked( $instance['show_kr'], 1 ); ?> id="<?php echo $this->get_field_id( 'show_kr' ); ?>" name="<?php echo $this->get_field_name( 'show_kr' ); ?>" /> 
			<label for="<?php echo $this->get_field_id( 'show_kr' ); ?>"><?php _e('Включить KR?', 'ccr'); ?></label>
		</p>
		
		<!-- Show JP? Checkbox -->
		<p>
			<input class="checkbox" type="checkbox" value="1" <?php checked( $instance['show_jp'], 1 ); ?> id="<?php echo $this->get_field_id( 'show_jp' ); ?>" name="<?php echo $this->get_field_name( 'show_jp' ); ?>" /> 
			<label for="<?php echo $this->get_field_id( 'show_jp' ); ?>"><?php _e('Включить JP?', 'ccr'); ?></label>
		</p>
		
		<!-- Show CH? Checkbox -->
		<p>
			<input class="checkbox" type="checkbox" value="1" <?php checked( $instance['show_ch'], 1 ); ?> id="<?php echo $this->get_field_id( 'show_ch' ); ?>" name="<?php echo $this->get_field_name( 'show_ch' ); ?>" /> 
			<label for="<?php echo $this->get_field_id( 'show_ch' ); ?>"><?php _e('Включить CH?', 'ccr'); ?></label>
		</p>
		
		<!-- Show GB? Checkbox -->
		<p>
			<input class="checkbox" type="checkbox" value="1" <?php checked( $instance['show_gb'], 1 ); ?> id="<?php echo $this->get_field_id( 'show_gb' ); ?>" name="<?php echo $this->get_field_name( 'show_gb' ); ?>" /> 
			<label for="<?php echo $this->get_field_id( 'show_gb' ); ?>"><?php _e('Включить GB?', 'ccr'); ?></label>
		</p>
	<?php
	}
}
     
     
    /**
     * Register languages.
     *
     */
    define( 'CCR_BASEDIR', dirname( plugin_basename(__FILE__) ) );
    #define( 'CCR_TEXTDOMAIN', 'ccr' );  //future
 
    add_action( 'plugins_loaded', 'ccr_wp_load_textdomain' );
  
    function ccr_wp_load_textdomain() {
	     load_plugin_textdomain( 'ccr', false, CCR_BASEDIR.'/languages');
    }
  
    /*
     * register with hook 'wp_print_styles'
     */
    add_action('wp_print_styles', 'add_ccr_stylesheet');

    /*
     * Enqueue style-file, if it exists.
     */

    function add_ccr_stylesheet() {
        $myStyleUrl = WP_PLUGIN_URL . '/currency-converter-rub/currency-converter-rub.css';
        $myStyleFile = WP_PLUGIN_DIR . '/currency-converter-rub/currency-converter-rub.css';
        if ( file_exists($myStyleFile) ) {
            wp_register_style('CurrencyConverter', $myStyleUrl);
            wp_enqueue_style( 'CurrencyConverter');
        }
    }
    
    
?>